@@ -1,4 +1,5 @@
-from typing import Any, Dict, List, Set
+import warnings
+from typing import Any, Dict, List, Optional, Set
 
 from datasets.arrow_dataset import Dataset
 from datasets.dataset_dict import DatasetDict
@@ -7,7 +8,7 @@ from torch.utils.data import Dataset as TorchDataset
 from transformers import BatchEncoding, PreTrainedTokenizerBase
 
 import dataquality as dq
-from dataquality.exceptions import GalileoException
+from dataquality.exceptions import GalileoException, GalileoWarning
 from dataquality.schemas.hf import HFCol
 from dataquality.schemas.ner import TaggingSchema
 from dataquality.schemas.split import conform_split
@@ -45,17 +46,15 @@ def infer_schema(label_list: List[str]) -> TaggingSchema:
 def tokenize_adjust_labels(
     all_samples_per_split: Dataset,
     tokenizer: PreTrainedTokenizerBase,
-    tag_names: List[str],
+    label_names: List[str],
 ) -> BatchEncoding:
-    schema = infer_schema(tag_names)
+    schema = infer_schema(label_names)
     label_tokenizer = LabelTokenizer(
-        all_samples_per_split, tokenizer, schema, tag_names
+        all_samples_per_split, tokenizer, schema, label_names
     )
 
     for k in range(label_tokenizer.num_samples):
-        label_tokenizer.initialize_batch(k)
-        if label_tokenizer.skip_batch:
-            continue
+        label_tokenizer.initialize_sample(k)
 
         for w_index_bpe, wid in enumerate(label_tokenizer.word_ids):
             # Logic for text_token_indices
@@ -71,51 +70,102 @@ def tokenize_adjust_labels(
         num_adjusted_labels = len(label_tokenizer.adjusted_label_indices)
         assert num_adjusted_labels == len(label_tokenizer.text_token_indices) + 2
 
-        label_tokenizer.update_totals_for_batch(k)
+        label_tokenizer.update_totals_for_sample(k)
 
     label_tokenizer.update_tokenized_samples()
     return label_tokenizer.tokenized_samples
 
 
-def _validate_dataset(dd: DatasetDict) -> None:
-    """Validates that the dataset passed in is a DatasetDict"""
+def _validate_dataset(dd: DatasetDict) -> DatasetDict:
+    """Validates that the dataset passed in is a DatasetDict
+
+    Also removes the id column if one is found (and replaces it) and validates
+    that `tags` or `ner_tags` is present
+    """
     if not isinstance(dd, DatasetDict):
         raise GalileoException(
             f"Expected DatasetDict but got object of type {type(dd)}. "
             f"If this is a dataset, you can create a dataset dict by running\n"
             "dd = datasets.DatasetDict({'your_split': your_Dataset})"
         )
+    for key in dd.keys():
+        ds = dd[key]
+        if HFCol.ner_tags not in ds.features:
+            if HFCol.tags in ds.features:
+                dd[key] = ds.rename_column(HFCol.tags, HFCol.ner_tags)
+                warnings.warn(
+                    f"{HFCol.tags} column found, it will be "
+                    f"renamed to {HFCol.ner_tags}",
+                    GalileoWarning,
+                )
+            else:
+                raise GalileoException("Each dataset must have either ner_tags or tags")
+        if HFCol.id in ds.features:
+            dd[key] = ds.remove_columns(HFCol.id)
+            warnings.warn(
+                f"{HFCol.id} column found, it will be replaced", GalileoWarning
+            )
+    return dd
+
+
+def _extract_labels_from_ds(dd: DatasetDict) -> List[str]:
+    """Extracts labels from a Dataset, if possible"""
+    ds_keys = list(dd.keys())
+    # Grab the first dataset available
+    ds = dd[ds_keys[0]]
+    # First, try to get the names from the ner_tags
+    if HFCol.ner_tags in ds.features and hasattr(
+        ds.features[HFCol.ner_tags].feature, "names"
+    ):
+        return ds.features[HFCol.ner_tags].feature.names
+    # If there is an "ner_labels" column (like from the Galileo export), we can use that
+    if HFCol.ner_labels in ds.features:
+        return ds[HFCol.ner_labels][0]
+    # The user must provide them
+    raise GalileoException(
+        "Could not extract labels from Dataset. Provide `label_names` to the "
+        "`tokenize_and_log_dataset` function as a list of strings"
+    )
 
 
 def tokenize_and_log_dataset(
-    ds: DatasetDict, tokenizer: PreTrainedTokenizerBase
+    dd: DatasetDict,
+    tokenizer: PreTrainedTokenizerBase,
+    label_names: Optional[List[str]] = None,
 ) -> DatasetDict:
     """This function tokenizes a huggingface DatasetDict and aligns the labels to BPE
 
     After tokenization, this function will also log the dataset(s) present in the
     DatasetDict
 
-    :param ds: DatasetDict from huggingface to log
+    :param dd: DatasetDict from huggingface to log
     :param tokenizer: The pretrained tokenizer from huggingface
     """
-    _validate_dataset(ds)
-    ds_keys = list(ds.keys())
-    tag_names = ds[ds_keys[0]].features[HFCol.ner_tags].feature.names
-    dq.set_tagging_schema(infer_schema(tag_names))
-    dq.set_labels_for_run(tag_names)
+    dd = _validate_dataset(dd)
+    if label_names is not None and len(label_names):
+        assert isinstance(
+            label_names, list
+        ), f"label_names must be of type list, but got {type(label_names)}"
+    else:
+        label_names = _extract_labels_from_ds(dd)
 
-    tokenized_dataset = ds.map(
+    dq.set_tagging_schema(infer_schema(label_names))
+    dq.set_labels_for_run(label_names)
+
+    tokenized_dataset = dd.map(
         tokenize_adjust_labels,
         batched=True,
-        fn_kwargs={"tokenizer": tokenizer, "tag_names": tag_names},
+        fn_kwargs={"tokenizer": tokenizer, "label_names": label_names},
     )
     splits = tokenized_dataset.keys()
-
     for split in splits:
         dq_split = conform_split(split)
-        ids = list(range(len(tokenized_dataset[split])))
-        tokenized_dataset[split] = tokenized_dataset[split].add_column(HFCol.id, ids)
         dataset: Dataset = tokenized_dataset[split]
+        # Filter out rows with no gold spans
+        dataset = dataset.filter(lambda row: len(row[HFCol.gold_spans]) != 0)
+        ids = list(range(len(dataset)))
+        dataset = dataset.add_column(HFCol.id, ids)
+        tokenized_dataset[split] = dataset
         dq.log_dataset(dataset, split=dq_split)  # type: ignore
     return tokenized_dataset
 
